% Auto-generated chapter 41 for bukhari
% Hadiths in this chapter: 28

\hadithdefcmd{bukhari}{2320}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، ح وَحَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ الْمُبَارَكِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ مُسْلِمٍ يَغْرِسُ غَرْسًا، أَوْ يَزْرَعُ زَرْعًا، فَيَأْكُلُ مِنْهُ طَيْرٌ أَوْ إِنْسَانٌ أَوْ بَهِيمَةٌ، إِلاَّ كَانَ لَهُ بِهِ صَدَقَةٌ ‏"‏‏.‏ وَقَالَ لَنَا مُسْلِمٌ حَدَّثَنَا أَبَانُ، حَدَّثَنَا قَتَادَةُ، حَدَّثَنَا أَنَسٌ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{2320}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, "There is none amongst the Muslims who plants a tree or sows seeds, and then a bird, or a person or an animal eats from it, but is regarded as a charitable gift for him}}
\hadithdefcmd{bukhari}{2321}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَالِمٍ الْحِمْصِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ زِيَادٍ الأَلْهَانِيُّ، عَنْ أَبِي أُمَامَةَ الْبَاهِلِيِّ،، قَالَ ـ وَرَأَى سِكَّةً وَشَيْئًا مِنْ آلَةِ الْحَرْثِ، فَقَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَدْخُلُ هَذَا بَيْتَ قَوْمٍ إِلاَّ أُدْخِلَهُ الذُّلُّ ‏"‏‏.‏ قَالَ أَبُو عَبْد اللَّهِ وَاسْمُ أَبِي أُمَامَةَ صُدَيُّ بْنُ عَجْلَانَ\hadithno{2321}\hadithtrans{Narrated Abu Umama al-Bahili:I saw some agricultural equipment and said: "I heard the Prophet (ﷺ) saying: "There is no house in which these equipment enters except that Allah will cause humiliation to enter it}}
\hadithdefcmd{bukhari}{2322}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَمْسَكَ كَلْبًا فَإِنَّهُ يَنْقُصُ كُلَّ يَوْمٍ مِنْ عَمَلِهِ قِيرَاطٌ، إِلاَّ كَلْبَ حَرْثٍ أَوْ مَاشِيَةٍ ‏"‏‏.‏ قَالَ ابْنُ سِيرِينَ وَأَبُو صَالِحٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ إِلاَّ كَلْبَ غَنَمٍ أَوْ حَرْثٍ أَوْ صَيْدٍ ‏"‏‏.‏ وَقَالَ أَبُو حَازِمٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ كَلْبَ صَيْدٍ أَوْ مَاشِيَةٍ ‏"‏‏.‏\hadithno{2322}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Whoever keeps a dog, one Qirat of the reward of his good deeds is deducted daily, unless the dog is used for guarding a farm or cattle." Abu Huraira (in another narration) said from the Prophet, "unless it is used for guarding sheep or farms, or for hunting." Narrated Abu Hazim from Abu Huraira: The Prophet (ﷺ) said, "A dog for guarding cattle or for hunting}}
\hadithdefcmd{bukhari}{2323}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ يَزِيدَ بْنِ خُصَيْفَةَ، أَنَّ السَّائِبَ بْنَ يَزِيدَ، حَدَّثَهُ أَنَّهُ، سَمِعَ سُفْيَانَ بْنَ أَبِي زُهَيْرٍ ـ رَجُلاً مِنْ أَزْدِ شَنُوءَةَ ـ وَكَانَ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنِ اقْتَنَى كَلْبًا لاَ يُغْنِي عَنْهُ زَرْعًا وَلاَ ضَرْعًا، نَقَصَ كُلَّ يَوْمٍ مِنْ عَمَلِهِ قِيرَاطٌ ‏"‏‏.‏ قُلْتُ أَنْتَ سَمِعْتَ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ إِي وَرَبِّ هَذَا الْمَسْجِدِ‏.‏\hadithno{2323}\hadithtrans{Narrated As-Sa'ib bin Yazid:Abu Sufyan bin Abu Zuhair, a man from Azd Shanu'a and one of the companions of the Prophet (ﷺ) said, "I heard Allah's Messenger (ﷺ) saying, 'If one keeps a dog which is meant for guarding neither a farm nor cattle, one Qirat of the reward of his good deeds is deducted daily." I said, "Did you hear this from Allah's Messenger (ﷺ)?" He said, "Yes, by the Lord of this Mosque}}
\hadithdefcmd{bukhari}{2324}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدٍ، سَمِعْتُ أَبَا سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَمَا رَجُلٌ رَاكِبٌ عَلَى بَقَرَةٍ الْتَفَتَتْ إِلَيْهِ‏.‏ فَقَالَتْ لَمْ أُخْلَقْ لِهَذَا، خُلِقْتُ لِلْحِرَاثَةِ، قَالَ آمَنْتُ بِهِ أَنَا وَأَبُو بَكْرٍ وَعُمَرُ، وَأَخَذَ الذِّئْبُ شَاةً فَتَبِعَهَا الرَّاعِي، فَقَالَ الذِّئْبُ مَنْ لَهَا يَوْمَ السَّبُعِ، يَوْمَ لاَ رَاعِيَ لَهَا غَيْرِي‏.‏ قَالَ آمَنْتُ بِهِ أَنَا وَأَبُو بَكْرٍ وَعُمَرُ ‏"‏‏.‏ قَالَ أَبُو سَلَمَةَ مَا هُمَا يَوْمَئِذٍ فِي الْقَوْمِ‏.‏\hadithno{2324}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "While a man was riding a cow, it turned towards him and said, 'I have not been created for this purpose (i.e. carrying), I have been created for ploughing." The Prophet (ﷺ) added, "I, Abu Bakr and `Umar believe in the story." The Prophet (ﷺ) went on, "A wolf caught a sheep, and when the shepherd chased it, the wolf said, 'Who will be its guard on the day of wild beasts, when there will be no shepherd for it except me?' "After narrating it, the Prophet (ﷺ) said, "I, Abu Bakr and `Umar too believe it." Abu Salama (a sub-narrator) said, "Abu Bakr and `Umar were not present then}}
\hadithdefcmd{bukhari}{2325}{حَدَّثَنَا الْحَكَمُ بْنُ نَافِعٍ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَتِ الأَنْصَارُ لِلنَّبِيِّ صلى الله عليه وسلم اقْسِمْ بَيْنَنَا وَبَيْنَ إِخْوَانِنَا النَّخِيلَ‏.‏ قَالَ ‏ "‏ لاَ ‏"‏‏.‏ فَقَالُوا تَكْفُونَا الْمَئُونَةَ وَنُشْرِكُكُمْ فِي الثَّمَرَةِ‏.‏ قَالُوا سَمِعْنَا وَأَطَعْنَا‏.‏\hadithno{2325}\hadithtrans{Narrated Abu Huraira:The Ansar said to the Prophet (ﷺ) "Distribute the date palm trees between us and our emigrant brothers." He replied, "No." The Ansar said (to the emigrants), "Look after the trees (water and watch them) and share the fruits with us." The emigrants said, "We listen and obey}}
\hadithdefcmd{bukhari}{2326}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ حَرَّقَ نَخْلَ بَنِي النَّضِيرِ وَقَطَعَ، وَهْىَ الْبُوَيْرَةُ، وَلَهَا يَقُولُ حَسَّانُ وَهَانَ عَلَى سَرَاةِ بَنِي لُؤَىٍّ حَرِيقٌ بِالْبُوَيْرَةِ مُسْتَطِيرٌ‏.‏\hadithno{2326}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) got the date palm trees of the tribe of Bani-An-Nadir burnt and the trees cut down at a place called Al-Buwaira . Hassan bin Thabit said in a poetic verse: "The chiefs of Bani Lu'ai found it easy to watch fire spreading at Al-Buwaira}}
\hadithdefcmd{bukhari}{2327}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ حَنْظَلَةَ بْنِ قَيْسٍ الأَنْصَارِيِّ، سَمِعَ رَافِعَ بْنَ خَدِيجٍ، قَالَ كُنَّا أَكْثَرَ أَهْلِ الْمَدِينَةِ مُزْدَرَعًا، كُنَّا نُكْرِي الأَرْضَ بِالنَّاحِيَةِ مِنْهَا مُسَمًّى لِسَيِّدِ الأَرْضِ، قَالَ فَمِمَّا يُصَابُ ذَلِكَ وَتَسْلَمُ الأَرْضُ، وَمِمَّا يُصَابُ الأَرْضُ وَيَسْلَمُ ذَلِكَ، فَنُهِينَا، وَأَمَّا الذَّهَبُ وَالْوَرِقُ فَلَمْ يَكُنْ يَوْمَئِذٍ‏.‏\hadithno{2327}\hadithtrans{Narrated Rafi` bin Khadij:We worked on farms more than anybody else in Medina. We used to rent the land at the yield of specific delimited portion of it to be given to the landlord. Sometimes the vegetation of that portion was affected by blights etc., while the rest remained safe and vice versa, so the Prophet (ﷺ) forbade this practice. At that time gold or silver were not used (for renting the land). If they provided the seeds, they would get so-and-so much}}
\hadithdefcmd{bukhari}{2328}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم عَامَلَ خَيْبَرَ بِشَطْرِ مَا يَخْرُجُ مِنْهَا مِنْ ثَمَرٍ أَوْ زَرْعٍ، فَكَانَ يُعْطِي أَزْوَاجَهُ مِائَةَ وَسْقٍ ثَمَانُونَ وَسْقَ تَمْرٍ وَعِشْرُونَ وَسْقَ شَعِيرٍ، فَقَسَمَ عُمَرُ خَيْبَرَ، فَخَيَّرَ أَزْوَاجَ النَّبِيِّ صلى الله عليه وسلم أَنْ يُقْطِعَ لَهُنَّ مِنَ الْمَاءِ وَالأَرْضِ، أَوْ يُمْضِيَ لَهُنَّ، فَمِنْهُنَّ مَنِ اخْتَارَ الأَرْضَ وَمِنْهُنَّ مَنِ اخْتَارَ الْوَسْقَ، وَكَانَتْ عَائِشَةُ اخْتَارَتِ الأَرْضَ‏.‏\hadithno{2328}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) concluded a contract with the people of Khaibar to utilize the land on the condition that half the products of fruits or vegetation would be their share. The Prophet (ﷺ) used to give his wives one hundred Wasqs each, eighty Wasqs of dates and twenty Wasqs of barley. (When `Umar became the Caliph) he gave the wives of the Prophet (ﷺ) the option of either having the land and water as their shares, or carrying on the previous practice. Some of them chose the land and some chose the Wasqs, and `Aisha chose the land}}
\hadithdefcmd{bukhari}{2329}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ عَامَلَ النَّبِيُّ صلى الله عليه وسلم خَيْبَرَ بِشَطْرِ مَا يَخْرُجُ مِنْهَا مِنْ ثَمَرٍ أَوْ زَرْعٍ‏.‏\hadithno{2329}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) made a deal with the people of Khaibar that they would have half the fruits and vegetation of the land they cultivated}}
\hadithdefcmd{bukhari}{2330}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ عَمْرٌو قُلْتُ لِطَاوُسٍ لَوْ تَرَكْتَ الْمُخَابَرَةَ فَإِنَّهُمْ يَزْعُمُونَ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْهُ‏.‏ قَالَ أَىْ عَمْرُو، إِنِّي أُعْطِيهِمْ وَأُغْنِيهِمْ، وَإِنَّ أَعْلَمَهُمْ أَخْبَرَنِي ـ يَعْنِي ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يَنْهَ عَنْهُ، وَلَكِنْ قَالَ ‏ "‏ أَنْ يَمْنَحَ أَحَدُكُمْ أَخَاهُ خَيْرٌ لَهُ مِنْ أَنْ يَأْخُذَ عَلَيْهِ خَرْجًا مَعْلُومًا ‏"‏‏.‏\hadithno{2330}\hadithtrans{Narrated `Amr:I said to Tawus, "I wish you would give up Mukhabara (Sharecropping), for the people say that the Prophet forbade it." On that Tawus replied, "O `Amr! I give the land to sharecroppers and help them. No doubt; the most learned man, namely Ibn `Abbas told me that the Prophet (ﷺ) had not forbidden it but said, 'It is more beneficial for one to give his land free to one's brother than to charge him a fixed rental}}
\hadithdefcmd{bukhari}{2331}{حَدَّثَنَا ابْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَعْطَى خَيْبَرَ الْيَهُودَ عَلَى أَنْ يَعْمَلُوهَا وَيَزْرَعُوهَا، وَلَهُمْ شَطْرُ مَا خَرَجَ مِنْهَا‏.‏\hadithno{2331}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) gave the land of Khaibar to the Jew's on the condition that they work on it and cultivate it, and be given half of its yield}}
\hadithdefcmd{bukhari}{2332}{حَدَّثَنَا صَدَقَةُ بْنُ الْفَضْلِ، أَخْبَرَنَا ابْنُ عُيَيْنَةَ، عَنْ يَحْيَى، سَمِعَ حَنْظَلَةَ الزُّرَقِيَّ، عَنْ رَافِعٍ ـ رضى الله عنه ـ قَالَ كُنَّا أَكْثَرَ أَهْلِ الْمَدِينَةِ حَقْلاً، وَكَانَ أَحَدُنَا يُكْرِي أَرْضَهُ، فَيَقُولُ هَذِهِ الْقِطْعَةُ لِي وَهَذِهِ لَكَ، فَرُبَّمَا أَخْرَجَتْ ذِهِ وَلَمْ تُخْرِجْ ذِهِ، فَنَهَاهُمُ النَّبِيُّ صلى الله عليه وسلم‏.‏\hadithno{2332}\hadithtrans{Narrated Rafi`:We worked on farms more than anybody else in Medina. We used to rent the land and say to the owner, "The yield of this portion is for us and the yield of that portion is for you (as the rent)." One of those portions might yield something and the other might not. So, the Prophet (ﷺ) forbade us to do so}}
\hadithdefcmd{bukhari}{2333}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَبُو ضَمْرَةَ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَمَا ثَلاَثَةُ نَفَرٍ يَمْشُونَ أَخَذَهُمُ الْمَطَرُ، فَأَوَوْا إِلَى غَارٍ فِي جَبَلٍ، فَانْحَطَّتْ عَلَى فَمِ غَارِهِمْ صَخْرَةٌ مِنَ الْجَبَلِ فَانْطَبَقَتْ عَلَيْهِمْ، فَقَالَ بَعْضُهُمْ لِبَعْضٍ انْظُرُوا أَعْمَالاً عَمِلْتُمُوهَا صَالِحَةً لِلَّهِ فَادْعُوا اللَّهَ بِهَا لَعَلَّهُ يُفَرِّجُهَا عَنْكُمْ‏.‏ قَالَ أَحَدُهُمُ اللَّهُمَّ إِنَّهُ كَانَ لِي وَالِدَانِ شَيْخَانِ كَبِيرَانِ، وَلِي صِبْيَةٌ صِغَارٌ كُنْتُ أَرْعَى عَلَيْهِمْ، فَإِذَا رُحْتُ عَلَيْهِمْ حَلَبْتُ، فَبَدَأْتُ بِوَالِدَىَّ أَسْقِيهِمَا قَبْلَ بَنِيَّ، وَإِنِّي اسْتَأْخَرْتُ ذَاتَ يَوْمٍ فَلَمْ آتِ حَتَّى أَمْسَيْتُ، فَوَجَدْتُهُمَا نَامَا، فَحَلَبْتُ كَمَا كُنْتُ أَحْلُبُ، فَقُمْتُ عِنْدَ رُءُوسِهِمَا، أَكْرَهُ أَنْ أُوقِظَهُمَا، وَأَكْرَهُ أَنْ أَسْقِيَ الصِّبْيَةَ، وَالصِّبْيَةُ يَتَضَاغَوْنَ عِنْدَ قَدَمَىَّ، حَتَّى طَلَعَ الْفَجْرُ، فَإِنْ كُنْتَ تَعْلَمُ أَنِّي فَعَلْتُهُ ابْتِغَاءَ وَجْهِكَ فَافْرُجْ لَنَا فَرْجَةً نَرَى مِنْهَا السَّمَاءَ‏.‏ فَفَرَجَ اللَّهُ فَرَأَوُا السَّمَاءَ‏.‏ وَقَالَ الآخَرُ اللَّهُمَّ إِنَّهَا كَانَتْ لِي بِنْتُ عَمٍّ أَحْبَبْتُهَا كَأَشَدِّ مَا يُحِبُّ الرِّجَالُ النِّسَاءَ، فَطَلَبْتُ مِنْهَا فَأَبَتْ حَتَّى أَتَيْتُهَا بِمِائَةِ دِينَارٍ، فَبَغَيْتُ حَتَّى جَمَعْتُهَا، فَلَمَّا وَقَعْتُ بَيْنَ رِجْلَيْهَا قَالَتْ يَا عَبْدَ اللَّهِ اتَّقِ اللَّهَ، وَلاَ تَفْتَحِ الْخَاتَمَ إِلاَّ بِحَقِّهِ، فَقُمْتُ، فَإِنْ كُنْتَ تَعْلَمُ أَنِّي فَعَلْتُهُ ابْتِغَاءَ وَجْهِكَ فَافْرُجْ عَنَّا فَرْجَةً‏.‏ فَفَرَجَ‏.‏ وَقَالَ الثَّالِثُ اللَّهُمَّ إِنِّي اسْتَأْجَرْتُ أَجِيرًا بِفَرَقِ أَرُزٍّ، فَلَمَّا قَضَى عَمَلَهُ قَالَ أَعْطِنِي حَقِّي‏.‏ فَعَرَضْتُ عَلَيْهِ، فَرَغِبَ عَنْهُ، فَلَمْ أَزَلْ أَزْرَعُهُ حَتَّى جَمَعْتُ مِنْهُ بَقَرًا وَرَاعِيهَا فَجَاءَنِي فَقَالَ اتَّقِ اللَّهَ‏.‏ فَقُلْتُ اذْهَبْ إِلَى ذَلِكَ الْبَقَرِ وَرُعَاتِهَا فَخُذْ‏.‏ فَقَالَ اتَّقِ اللَّهَ وَلاَ تَسْتَهْزِئْ بِي‏.‏ فَقُلْتُ إِنِّي لاَ أَسْتَهْزِئُ بِكَ فَخُذْ‏.‏ فَأَخَذَهُ، فَإِنْ كُنْتَ تَعْلَمُ أَنِّي فَعَلْتُ ذَلِكَ ابْتِغَاءَ وَجْهِكَ فَافْرُجْ مَا بَقِيَ، فَفَرَجَ اللَّهُ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ وَقَالَ ابْنُ عُقْبَةَ عَنْ نَافِعٍ فَسَعَيْتُ‏.‏\hadithno{2333}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) said, "While three men were walking, It started raining and they took shelter (refuge) in a cave in a mountain. A big rock rolled down from the mountain and closed the mouth of the cave. They said to each other, "Think of good deeds which you did for Allah's sake only, and invoke Allah by giving reference to those deeds so that He may remove this rock from you." One of them said, 'O Allah! I had old parents and small children and I used to graze the sheep for them. On my return to them in the evening, I used to milk (the sheep) and start providing my parents first of all before my children. One day I was delayed and came late at night and found my parents sleeping. I milked (the sheep) as usual and stood by their heads. I hated to wake them up and disliked to give milk to my children before them, although my children were weeping (because of hunger) at my feet till the day dawned. O Allah! If I did this for Your sake only, kindly remove the rock so that we could see the sky through it.' So, Allah removed the rock a little and they saw the sky. The second man said, 'O Allah! I was in love with a cousin of mine like the deepest love a man may have for a woman. I wanted to outrage her chastity but she refused unless I gave her one hundred Dinars. So, I struggled to collect that amount. And when I sat between her legs, she said, 'O Allah's slave! Be afraid of Allah and do not deflower me except rightfully (by marriage).' So, I got up. O Allah! If I did it for Your sake only, please remove the rock.' The rock shifted a little more. Then the third man said, 'O Allah! I employed a laborer for a Faraq of rice and when he finished his job and demanded his right, I presented it to him, but he refused to take it. So, I sowed the rice many time till I gathered cows and their shepherd (from the yield). (Then after some time) He came and said to me, 'Fear Allah (and give me my right)." I said, 'Go and take those cows and the shepherd.' He said, 'Be afraid of Allah! Don't mock at me.' I said, 'I am not mocking at you. Take (all that).' So, he took all that. O Allah! If I did that for Your sake only, please remove the rest of the rock.' So, Allah removed the rock}}
\hadithdefcmd{bukhari}{2334}{حَدَّثَنَا صَدَقَةُ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، قَالَ قَالَ عُمَرُ ـ رضى الله عنه ـ لَوْلاَ آخِرُ الْمُسْلِمِينَ مَا فَتَحْتُ قَرْيَةً إِلاَّ قَسَمْتُهَا بَيْنَ أَهْلِهَا كَمَا قَسَمَ النَّبِيُّ صلى الله عليه وسلم خَيْبَرَ‏.‏\hadithno{2334}\hadithtrans{Narrated Zaid bin Aslam from his father:`Umar said, "But for the future Muslim generations, I would have distributed the land of the villages I conquer among the soldiers as the Prophet (ﷺ) distributed the land of Khaibar}}
\hadithdefcmd{bukhari}{2335}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْمَرَ أَرْضًا لَيْسَتْ لأَحَدٍ فَهْوَ أَحَقُّ ‏"‏‏.‏ قَالَ عُرْوَةُ قَضَى بِهِ عُمَرُ ـ رضى الله عنه ـ فِي خِلاَفَتِهِ‏.‏\hadithno{2335}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "He who cultivates land that does not belong to anybody is more rightful (to own it)." `Urwa said, "`Umar gave the same verdict in his Caliphate}}
\hadithdefcmd{bukhari}{2336}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم أُرِيَ وَهْوَ فِي مُعَرَّسِهِ مِنْ ذِي الْحُلَيْفَةِ فِي بَطْنِ الْوَادِي، فَقِيلَ لَهُ إِنَّكَ بِبَطْحَاءَ مُبَارَكَةٍ‏.‏ فَقَالَ مُوسَى وَقَدْ أَنَاخَ بِنَا سَالِمٌ بِالْمُنَاخِ الَّذِي كَانَ عَبْدُ اللَّهِ يُنِيخُ بِهِ، يَتَحَرَّى مُعَرَّسَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهْوَ أَسْفَلُ مِنَ الْمَسْجِدِ الَّذِي بِبَطْنِ الْوَادِي، بَيْنَهُ وَبَيْنَ الطَّرِيقِ وَسَطٌ مِنْ ذَلِكَ‏.‏\hadithno{2336}\hadithtrans{Narrated `Abdullah bin `Umar:While the Prophet (ﷺ) was passing the night at his place of rest in Dhul-Hulaifa in the bottom of the valley (of Aqiq), he saw a dream and it was said to him, "You are in a blessed valley." Musa said, "Salim let our camels kneel at the place where `Abdullah used to make his camel kneel, seeking the place where Allah's Messenger (ﷺ) used to take a rest, which is situated below the mosque which is in the bottom of the valley; it is midway between the mosque and the road}}
\hadithdefcmd{bukhari}{2337}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا شُعَيْبُ بْنُ إِسْحَاقَ، عَنِ الأَوْزَاعِيِّ، قَالَ حَدَّثَنِي يَحْيَى، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنْ عُمَرَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّيْلَةَ أَتَانِي آتٍ مِنْ رَبِّي وَهْوَ بِالْعَقِيقِ أَنْ صَلِّ فِي هَذَا الْوَادِي الْمُبَارَكِ وَقُلْ عُمْرَةٌ فِي حَجَّةٍ ‏"‏‏.‏\hadithno{2337}\hadithtrans{Narrated `Umar:While the Prophet (ﷺ) was in Al-`Aqiq he said, "Someone (meaning Gabriel) came to me from my Lord tonight (in my dream) and said, 'Offer the prayer in this blessed valley and say (I intend to perform) `Umra along with Hajj (together)}}
\hadithdefcmd{bukhari}{2338}{حَدَّثَنَا أَحْمَدُ بْنُ الْمِقْدَامِ، حَدَّثَنَا فُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنَا مُوسَى، أَخْبَرَنَا نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ وَقَالَ عَبْدُ الرَّزَّاقِ أَخْبَرَنَا ابْنُ جُرَيْجٍ قَالَ حَدَّثَنِي مُوسَى بْنُ عُقْبَةَ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ أَنَّ عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنهما ـ أَجْلَى الْيَهُودَ وَالنَّصَارَى مِنْ أَرْضِ الْحِجَازِ، وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَمَّا ظَهَرَ عَلَى خَيْبَرَ أَرَادَ إِخْرَاجَ الْيَهُودِ مِنْهَا، وَكَانَتِ الأَرْضُ حِينَ ظَهَرَ عَلَيْهَا لِلَّهِ وَلِرَسُولِهِ صلى الله عليه وسلم وَلِلْمُسْلِمِينَ، وَأَرَادَ إِخْرَاجَ الْيَهُودِ، مِنْهَا فَسَأَلَتِ الْيَهُودُ رَسُولَ اللَّهِ صلى الله عليه وسلم لِيُقِرَّهُمْ بِهَا أَنْ يَكْفُوا عَمَلَهَا وَلَهُمْ نِصْفُ الثَّمَرِ، فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نُقِرُّكُمْ بِهَا عَلَى ذَلِكَ مَا شِئْنَا ‏"‏‏.‏ فَقَرُّوا بِهَا حَتَّى أَجْلاَهُمْ عُمَرُ إِلَى تَيْمَاءَ وَأَرِيحَاءَ‏.‏\hadithno{2338}\hadithtrans{Narrated Ibn `Umar:`Umar expelled the Jews and the Christians from Hijaz. When Allah's Messenger (ﷺ) had conquered Khaibar, he wanted to expel the Jews from it as its land became the property of Allah, His Apostle, and the Muslims. Allah's Messenger (ﷺ) intended to expel the Jews but they requested him to let them stay there on the condition that they would do the labor and get half of the fruits. Allah's Messenger (ﷺ) told them, "We will let you stay on this condition, as long as we wish." So, they (i.e. Jews) kept on living there until `Umar forced them to go towards Taima' and Ariha}}
\hadithdefcmd{bukhari}{2339}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا الأَوْزَاعِيُّ، عَنْ أَبِي النَّجَاشِيِّ، مَوْلَى رَافِعِ بْنِ خَدِيجٍ سَمِعْتُ رَافِعَ بْنَ خَدِيجِ بْنِ رَافِعٍ، عَنْ عَمِّهِ، ظُهَيْرِ بْنِ رَافِعٍ قَالَ ظُهَيْرٌ لَقَدْ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَمْرٍ كَانَ بِنَا رَافِقًا‏.‏ قُلْتُ مَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَهْوَ حَقٌّ‏.‏ قَالَ دَعَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَا تَصْنَعُونَ بِمَحَاقِلِكُمْ ‏"‏‏.‏ قُلْتُ نُؤَاجِرُهَا عَلَى الرُّبُعِ وَعَلَى الأَوْسُقِ مِنَ التَّمْرِ وَالشَّعِيرِ‏.‏ قَالَ ‏"‏ لا تَفْعَلُوا ازْرَعُوهَا أَوْ أَزْرِعُوهَا أَوْ أَمْسِكُوهَا ‏"‏‏.‏ قَالَ رَافِعٌ قُلْتُ سَمْعًا وَطَاعَةً‏.‏\hadithno{2339}\hadithtrans{Narrated Rafi` bin Khadij:My uncle Zuhair said, "Allah's Messenger (ﷺ) forbade us to do a thing which was a source of help to us." I said, "Whatever Allah's Messenger (ﷺ) said was right." He said, "Allah's Messenger (ﷺ) sent for me and asked, 'What are you doing with your farms?' I replied, 'We give our farms on rent on the basis that we get the yield produced at the banks of the water streams (rivers) for the rent, or rent it for some Wasqs of barley and dates.' Allah's Messenger (ﷺ) said, 'Do not do so, but cultivate (the land) yourselves or let it be cultivated by others gratis, or keep it uncultivated.' I said, 'We hear and obey}}
\hadithdefcmd{bukhari}{2341}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، أَخْبَرَنَا الأَوْزَاعِيُّ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ كَانُوا يَزْرَعُونَهَا بِالثُّلُثِ وَالرُّبُعِ وَالنِّصْفِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ كَانَتْ لَهُ أَرْضٌ فَلْيَزْرَعْهَا أَوْ لِيَمْنَحْهَا، فَإِنْ لَمْ يَفْعَلْ فَلْيُمْسِكْ أَرْضَهُ ‏"‏‏.‏ وَقَالَ الرَّبِيعُ بْنُ نَافِعٍ أَبُو تَوْبَةَ حَدَّثَنَا مُعَاوِيَةُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ كَانَتْ لَهُ أَرْضٌ فَلْيَزْرَعْهَا أَوْ لِيَمْنَحْهَا أَخَاهُ، فَإِنْ أَبَى فَلْيُمْسِكْ أَرْضَهُ ‏"‏‏.‏\hadithno{2341}\hadithtrans{Narrated Jabir:The people used to rent their land for cultivation for one-third, one-fourth or half its yield. The Prophet said, "Whoever has land should cultivate it himself or give it to his (Muslim) brother gratis; otherwise keep it uncultivated." Narrated Abu Huraira: Allah's Messenger (ﷺ) said, "Whoever has land should cultivate it himself or give it to his (Muslim) brother gratis; otherwise he should keep it uncultivated}}
\hadithdefcmd{bukhari}{2342}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، قَالَ ذَكَرْتُهُ لِطَاوُسٍ فَقَالَ يُزْرِعُ، قَالَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ إِنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يَنْهَ عَنْهُ وَلَكِنْ قَالَ ‏ "‏ أَنْ يَمْنَحَ أَحَدُكُمْ أَخَاهُ خَيْرٌ لَهُ مِنْ أَنْ يَأْخُذَ شَيْئًا مَعْلُومًا ‏"‏‏.‏\hadithno{2342}\hadithtrans{Narrated `Amr:When I mentioned it (i.e. the narration of Rafi` 'bin Khadij: no. 532) to Tawus, he said, "It is permissible to rent the land for cultivation, for Ibn `Abbas said, 'The Prophet (ﷺ) did not forbid that, but said: One had better give the land to one's brother gratis rather than charge a certain amount for it}}
\hadithdefcmd{bukhari}{2344}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ كَانَ يُكْرِي مَزَارِعَهُ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ وَعُثْمَانَ وَصَدْرًا مِنْ إِمَارَةِ مُعَاوِيَةَ‏.‏ ثُمَّ حُدِّثَ عَنْ رَافِعِ بْنِ خَدِيجٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ كِرَاءِ الْمَزَارِعِ، فَذَهَبَ ابْنُ عُمَرَ إِلَى رَافِعٍ فَذَهَبْتُ مَعَهُ، فَسَأَلَهُ فَقَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ كِرَاءِ الْمَزَارِعِ‏.‏ فَقَالَ ابْنُ عُمَرَ قَدْ عَلِمْتَ أَنَّا كُنَّا نُكْرِي مَزَارِعَنَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمَا عَلَى الأَرْبِعَاءِ وَبِشَىْءٍ مِنَ التِّبْنِ‏.‏\hadithno{2344}\hadithtrans{Narrated Nafi`:Ibn `Umar used to rent his farms in the time of Abu Bakr, `Umar, `Uthman, and in the early days of Muawiya. Then he was told the narration of Rafi` 'bin Khadij that the Prophet (ﷺ) had forbidden the renting of farms. Ibn `Umar went to Rafi` and I accompanied him. He asked Rafi` who replied that the Prophet had forbidden the renting of farms. Ibn `Umar said, "You know that we used to rent our farms in the lifetime of Allah's Messenger (ﷺ) for the yield of the banks of the water streams (rivers) and for certain amount of figs}}
\hadithdefcmd{bukhari}{2345}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي سَالِمٌ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ كُنْتُ أَعْلَمُ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّ الأَرْضَ تُكْرَى‏.‏ ثُمَّ خَشِيَ عَبْدُ اللَّهِ أَنْ يَكُونَ النَّبِيُّ صلى الله عليه وسلم قَدْ أَحْدَثَ فِي ذَلِكَ شَيْئًا لَمْ يَكُنْ يَعْلَمُهُ، فَتَرَكَ كِرَاءَ الأَرْضِ‏.‏\hadithno{2345}\hadithtrans{Narrated Salim:`Abdullah bin `Umar said, "I knew that the land was rented for cultivation in the lifetime of Allah's Apostle ." Later on Ibn `Umar was afraid that the Prophet (ﷺ) had forbidden it, and he had no knowledge of it, so he gave up renting his land}}
\hadithdefcmd{bukhari}{2347}{حَدَّثَنَا عَمْرُو بْنُ خَالِدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ حَنْظَلَةَ بْنِ قَيْسٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ حَدَّثَنِي عَمَّاىَ، أَنَّهُمْ كَانُوا يُكْرُونَ الأَرْضَ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم بِمَا يَنْبُتُ عَلَى الأَرْبِعَاءِ أَوْ شَىْءٍ يَسْتَثْنِيهِ صَاحِبُ الأَرْضِ فَنَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ ذَلِكَ فَقُلْتُ لِرَافِعٍ فَكَيْفَ هِيَ بِالدِّينَارِ وَالدِّرْهَمِ فَقَالَ رَافِعٌ لَيْسَ بِهَا بَأْسٌ بِالدِّينَارِ وَالدِّرْهَمِ‏.‏ وَقَالَ اللَّيْثُ وَكَانَ الَّذِي نُهِيَ عَنْ ذَلِكَ مَا لَوْ نَظَرَ فِيهِ ذَوُو الْفَهْمِ بِالْحَلاَلِ وَالْحَرَامِ لَمْ يُجِيزُوهُ، لِمَا فِيهِ مِنَ الْمُخَاطَرَةِ‏.‏\hadithno{2347}\hadithtrans{Narrated Hanzala bin Qais:Rafi` bin Khadij said, "My two uncles told me that they (i.e. the companions of the Prophet) used to rent the land in the lifetime of the Prophet (ﷺ) for the yield on the banks of water streams (rivers) or for a portion of the yield stipulated by the owner of the land. The Prophet (ﷺ) forbade it." I said to Rafi`, "What about renting the land for Dinars and Dirhams?" He replied, "There is no harm in renting for Dinars- Dirhams. Al-Laith said, "If those who have discernment for distinguishing what is legal from what is illegal looked into what has been forbidden concerning this matter they would not permit it, for it is surrounded with dangers}}
\hadithdefcmd{bukhari}{2348}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، حَدَّثَنَا فُلَيْحٌ، حَدَّثَنَا هِلاَلٌ، وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا فُلَيْحٌ، عَنْ هِلاَلِ بْنِ عَلِيٍّ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَوْمًا يُحَدِّثُ وَعِنْدَهُ رَجُلٌ مِنْ أَهْلِ الْبَادِيَةِ ‏ "‏ أَنَّ رَجُلاً مِنْ أَهْلِ الْجَنَّةِ اسْتَأْذَنَ رَبَّهُ فِي الزَّرْعِ فَقَالَ لَهُ أَلَسْتَ فِيمَا شِئْتَ قَالَ بَلَى وَلَكِنِّي أُحِبُّ أَنْ أَزْرَعَ‏.‏ قَالَ فَبَذَرَ فَبَادَرَ الطَّرْفَ نَبَاتُهُ وَاسْتِوَاؤُهُ وَاسْتِحْصَادُهُ، فَكَانَ أَمْثَالَ الْجِبَالِ فَيَقُولُ اللَّهُ دُونَكَ يَا ابْنَ آدَمَ، فَإِنَّهُ لاَ يُشْبِعُكَ شَىْءٌ ‏"‏‏.‏ فَقَالَ الأَعْرَابِيُّ وَاللَّهِ لاَ تَجِدُهُ إِلاَّ قُرَشِيًّا أَوْ أَنْصَارِيًّا، فَإِنَّهُمْ أَصْحَابُ زَرْعٍ، وَأَمَّا نَحْنُ فَلَسْنَا بِأَصْحَابِ زَرْعٍ‏.‏ فَضَحِكَ النَّبِيُّ صلى الله عليه وسلم‏.‏\hadithno{2348}\hadithtrans{Narrated Abu Huraira:Once the Prophet (ﷺ) was narrating (a story), while a bedouin was sitting with him. "One of the inhabitants of Paradise will ask Allah to allow him to cultivate the land. Allah will ask him, 'Are you not living in the pleasures you like?' He will say, 'Yes, but I like to cultivate the land.' " The Prophet (ﷺ) added, "When the man (will be permitted he) will sow the seeds and the plants will grow up and get ripe, ready for reaping and so on till it will be as huge as mountains within a wink. Allah will then say to him, 'O son of Adam! Take here you are, gather (the yield); nothing satisfies you.' " On that, the bedouin said, "The man must be either from Quraish (i.e. an emigrant) or an Ansari, for they are farmers, whereas we are not farmers." The Prophet (ﷺ) smiled (at this)}}
\hadithdefcmd{bukhari}{2349}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ ـ رضى الله عنه ـ أَنَّهُ قَالَ إِنَّا كُنَّا نَفْرَحُ بِيَوْمِ الْجُمُعَةِ، كَانَتْ لَنَا عَجُوزٌ تَأْخُذُ مِنْ أُصُولِ سِلْقٍ لَنَا كُنَّا نَغْرِسُهُ فِي أَرْبِعَائِنَا فَتَجْعَلُهُ فِي قِدْرٍ لَهَا فَتَجْعَلُ فِيهِ حَبَّاتٍ مِنْ شَعِيرٍ لاَ أَعْلَمُ إِلاَّ أَنَّهُ قَالَ لَيْسَ فِيهِ شَحْمٌ وَلاَ وَدَكٌ، فَإِذَا صَلَّيْنَا الْجُمُعَةَ زُرْنَاهَا فَقَرَّبَتْهُ، إِلَيْنَا فَكُنَّا نَفْرَحُ بِيَوْمِ الْجُمُعَةِ مِنْ أَجْلِ ذَلِكَ وَمَا كُنَّا نَتَغَدَّى وَلاَ نَقِيلُ إِلاَّ بَعْدَ الْجُمُعَةَ‏.‏\hadithno{2349}\hadithtrans{Narrated Sahl bin Sa`d:We used to be very happy on Friday as an old lady used to cut some roots of the Silq, which we used to plant on the banks of our small water streams, and cook them in a pot of her's, adding to them, some grains of barley. (Ya'qub, the sub-narrator said, "I think the narrator mentioned that the food did not contain fat or melted fat (taken from meat).") When we offered the Friday prayer we would go to her and she would serve us with the dish. So, we used to be happy on Fridays because of that. We used not to take our meals or the midday nap except after the Jumua prayer (i.e. Friday prayer)}}
\hadithdefcmd{bukhari}{2350}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ يَقُولُونَ إِنَّ أَبَا هُرَيْرَةَ يُكْثِرُ الْحَدِيثَ‏.‏ وَاللَّهُ الْمَوْعِدُ، وَيَقُولُونَ مَا لِلْمُهَاجِرِينَ وَالأَنْصَارِ لاَ يُحَدِّثُونَ مِثْلَ أَحَادِيثِهِ وَإِنَّ إِخْوَتِي مِنَ الْمُهَاجِرِينَ كَانَ يَشْغَلُهُمُ الصَّفْقُ بِالأَسْوَاقِ، وَإِنَّ إِخْوَتِي مِنَ الأَنْصَارِ كَانَ يَشْغَلُهُمْ عَمَلُ أَمْوَالِهِمْ، وَكُنْتُ امْرَأً مِسْكِينًا أَلْزَمُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى مِلْءِ بَطْنِي، فَأَحْضُرُ حِينَ يَغِيبُونَ وَأَعِي حِينَ يَنْسَوْنَ، وَقَالَ النَّبِيُّ صلى الله عليه وسلم يَوْمًا ‏"‏ لَنْ يَبْسُطَ أَحَدٌ مِنْكُمْ ثَوْبَهُ حَتَّى أَقْضِيَ مَقَالَتِي هَذِهِ، ثُمَّ يَجْمَعَهُ إِلَى صَدْرِهِ، فَيَنْسَى مِنْ مَقَالَتِي شَيْئًا أَبَدًا ‏"‏‏.‏ فَبَسَطْتُ نَمِرَةً لَيْسَ عَلَىَّ ثَوْبٌ غَيْرَهَا، حَتَّى قَضَى النَّبِيُّ صلى الله عليه وسلم مَقَالَتَهُ، ثُمَّ جَمَعْتُهَا إِلَى صَدْرِي، فَوَالَّذِي بَعَثَهُ بِالْحَقِّ مَا نَسِيتُ مِنْ مَقَالَتِهِ تِلْكَ إِلَى يَوْمِي هَذَا، وَاللَّهِ لَوْلاَ آيَتَانِ فِي كِتَابِ اللَّهِ مَا حَدَّثْتُكُمْ شَيْئًا أَبَدًا ‏\{‏إِنَّ الَّذِينَ يَكْتُمُونَ مَا أَنْزَلْنَا مِنَ الْبَيِّنَاتِ‏\}‏ إِلَى قَوْلِهِ ‏\{‏الرَّحِيمُ‏\}‏\hadithno{2350}\hadithtrans{Narrated Abu Huraira:The people say that Abu Huraira narrates too many narrations. In fact Allah knows whether I say the truth or not. They also ask, "Why do the emigrants and the Ansar not narrate as he does?" In fact, my emigrant brethren were busy trading in the markets, and my Ansar brethren were busy with their properties. I was a poor man keeping the company of Allah's Messenger (ﷺ) and was satisfied with what filled my stomach. So, I used to be present while they (i.e. the emigrants and the Ansar) were absent, and I used to remember while they forgot (the Hadith). One day the Prophet (ﷺ) said, "Whoever spreads his sheet till I finish this statement of mine and then gathers it on his chest, will never forget anything of my statement." So, I spread my covering sheet which was the only garment I had, till the Prophet (ﷺ) finished his statement and then I gathered it over my chest. By Him Who had sent him (i.e. Allah's Apostle) with the truth, since then I did not forget even a single word of that statement of his, until this day of mine. By Allah, but for two verses in Allah's Book, I would never have related any narration (from the Prophet). (These two verses are): "Verily! Those who conceal the clear signs and the guidance which we have sent down .....(up to) the Merciful}}
